@@ -1,9 +1,6 @@
 from pollination_dsl.dag import Inputs, DAG, task, Outputs
 from dataclasses import dataclass
-from pollination.honeybee_radiance.sky import GenSkyWithCertainIllum
-from pollination.honeybee_radiance.octree import CreateOctreeWithSky
-from pollination.honeybee_radiance.translate import CreateRadianceFolderGrid
-from pollination.honeybee_radiance.grid import SplitGridFolder, MergeFolderData
+from pollination.honeybee_radiance.grid import MergeFolderData
 from pollination.honeybee_radiance.raytrace import RayTracingDaylightFactor
 
 # input/output alias
@@ -14,6 +11,9 @@ from pollination.alias.inputs.grid import grid_filter_input, \
 from pollination.alias.outputs.daylight import daylight_factor_results
 
 
+from ._prepare_folder import DaylightFactorPrepareFolder
+
+
 @dataclass
 class DaylightFactorEntryPoint(DAG):
     """Daylight factor entry point."""
@@ -39,7 +39,7 @@ class DaylightFactorEntryPoint(DAG):
         'precedence over the cpu_count and can be used to ensure that '
         'the parallelization does not result in generating unnecessarily small '
         'sensor grids. The default value is set to 1, which means that the '
-        'cpu_count is always respected.', default=1,
+        'cpu_count is always respected.', default=500,
         spec={'type': 'integer', 'minimum': 1},
         alias=min_sensor_count_input
     )
@@ -59,91 +59,50 @@ class DaylightFactorEntryPoint(DAG):
         alias=grid_filter_input
     )
 
-    @task(template=GenSkyWithCertainIllum)
-    def generate_sky(self):
+    @task(template=DaylightFactorPrepareFolder)
+    def prepare_daylight_factor_folder(
+            self, cpu_count=cpu_count, min_sensor_count=min_sensor_count,
+            grid_filter=grid_filter, model=model
+        ):
         return [
             {
-                'from': GenSkyWithCertainIllum()._outputs.sky,
-                'to': 'resources/100000_lux.sky'
-            }
-        ]
-
-    @task(template=CreateRadianceFolderGrid)
-    def create_rad_folder(
-        self, input_model=model, grid_filter=grid_filter
-            ):
-        """Translate the input model to a radiance folder."""
-        return [
-            {
-                'from': CreateRadianceFolderGrid()._outputs.model_folder,
+                'from': DaylightFactorPrepareFolder()._outputs.model_folder,
                 'to': 'model'
             },
             {
-                'from': CreateRadianceFolderGrid()._outputs.bsdf_folder,
-                'to': 'model/bsdf'
+                'from': DaylightFactorPrepareFolder()._outputs.resources,
+                'to': 'resources'
             },
             {
-                'from': CreateRadianceFolderGrid()._outputs.model_sensor_grids_file,
-                'to': 'results/daylight-factor/grids_info.json'
+                'from': DaylightFactorPrepareFolder()._outputs.results,
+                'to': 'results'
             },
             {
-                'from': CreateRadianceFolderGrid()._outputs.sensor_grids,
-                'description': 'Sensor grids information.'
-            }
-        ]
-
-    @task(
-        template=CreateOctreeWithSky, needs=[generate_sky, create_rad_folder]
-    )
-    def create_octree(
-        self, model=create_rad_folder._outputs.model_folder,
-        sky=generate_sky._outputs.sky
-    ):
-        """Create octree from radiance folder and sky."""
-        return [
-            {
-                'from': CreateOctreeWithSky()._outputs.scene_file,
-                'to': 'resources/scene.oct'
-            }
-        ]
-
-    @task(
-        template=SplitGridFolder, needs=[create_rad_folder],
-        sub_paths={'input_folder': 'grid'}
-    )
-    def split_grid_folder(
-        self, input_folder=create_rad_folder._outputs.model_folder,
-        cpu_count=cpu_count, cpus_per_grid=1, min_sensor_count=min_sensor_count
-    ):
-        """Split sensor grid folder based on the number of CPUs"""
-        return [
-            {
-                'from': SplitGridFolder()._outputs.output_folder,
-                'to': 'resources/grid'
+                'from': DaylightFactorPrepareFolder()._outputs.initial_results,
+                'to': 'initial_results'
             },
             {
-                'from': SplitGridFolder()._outputs.dist_info,
-                'to': 'initial_results/_redist_info.json'
-            },
-            {
-                'from': SplitGridFolder()._outputs.sensor_grids,
-                'description': 'Sensor grids information.'
+                'from': DaylightFactorPrepareFolder()._outputs.sensor_grids
             }
         ]
 
     @task(
         template=RayTracingDaylightFactor,
-        needs=[create_rad_folder, split_grid_folder, create_octree],
-        loop=split_grid_folder._outputs.sensor_grids,
+        needs=[prepare_daylight_factor_folder],
+        loop=prepare_daylight_factor_folder._outputs.sensor_grids,
         sub_folder='initial_results/{{item.full_id}}',  # subfolder for each grid
-        sub_paths={'grid': '{{item.full_id}}.pts'}  # sensor_grid sub_path
+        sub_paths={
+            'grid': 'grid/{{item.full_id}}.pts',
+            'scene_file': 'scene.oct',
+            'bsdf': 'bsdf'
+        }
     )
     def daylight_factor_ray_tracing(
         self,
         radiance_parameters=radiance_parameters,
-        scene_file=create_octree._outputs.scene_file,
-        grid=split_grid_folder._outputs.output_folder,
-        bsdf_folder=create_rad_folder._outputs.bsdf_folder
+        scene_file=prepare_daylight_factor_folder._outputs.resources,
+        grid=prepare_daylight_factor_folder._outputs.resources,
+        bsdf_folder=prepare_daylight_factor_folder._outputs.model_folder
     ):
         return [
             {
